@@ -22,9 +22,10 @@
 #define FILESELECTDLG_H
 
 #include <QDialog>
-#include <QSet>
 #include <QSortFilterProxyModel>
-#include <ksharedconfig.h>
+
+#include <KSharedConfig>
+
 #include <util/constants.h>
 #include "ui_fileselectdlg.h"
 
@@ -52,7 +53,7 @@ namespace kt
 
     public:
         FileSelectDlg(kt::QueueManager* qman, kt::GroupManager* gman, const QString& group_hint, QWidget* parent);
-        virtual ~FileSelectDlg();
+        ~FileSelectDlg() override;
 
         int execute(bt::TorrentInterface* tc, bool* start, bool* skip_check, const QString& location_hint);
 
@@ -70,8 +71,8 @@ namespace kt
         void saveState(KSharedConfigPtr cfg);
 
     protected slots:
-        virtual void reject();
-        virtual void accept();
+        void reject() override;
+        void accept() override;
         void selectAll();
         void selectNone();
         void invertSelection();
@@ -84,7 +85,7 @@ namespace kt
         void setFilter(const QString& filter);
         void updateExistingFiles();
         void moveCompletedToggled(bool on);
-        QMenu* createHistoryMenu(const QSet<QString> & urls, const char* slot);
+        QMenu* createHistoryMenu(const QStringList& urls, const char* slot);
         void clearDownloadLocationHistory();
         void clearMoveOnCompletionLocationHistory();
         void downloadLocationHistoryTriggered(QAction* act);
@@ -106,8 +107,8 @@ namespace kt
         kt::Group* initial_group;
         bool show_file_tree;
         QSortFilterProxyModel* filter_model;
-        QSet<QString> download_location_history;
-        QSet<QString> move_on_completion_location_history;
+        QStringList download_location_history;
+        QStringList move_on_completion_location_history;
         bt::Uint64 already_downloaded;
     };
 }
