@@ -16,26 +16,31 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #include "pastedialog.h"
 #include "core.h"
-#include <QClipboard>
+
 #include <QApplication>
-#include <QUrl>
+#include <QClipboard>
 #include <QLineEdit>
+#include <QUrl>
+
+#include <KConfigGroup>
+#include <KLocalizedString>
 #include <KMessageBox>
-#include <klocalizedstring.h>
+#include <KSharedConfig>
 #include <KStandardGuiItem>
-#include <ksharedconfig.h>
+
 #include <groups/groupmanager.h>
 
 namespace kt
 {
-    PasteDialog::PasteDialog(Core* core, QWidget* parent, Qt::WFlags fl)
-        : KDialog(parent, fl)
+    PasteDialog::PasteDialog(Core* core, QWidget* parent, Qt::WindowFlags fl)
+        : QDialog(parent, fl)
     {
-        setupUi(mainWidget());
+        setupUi(this);
         setWindowTitle(i18n("Open an URL"));
 
         m_core = core;
@@ -44,6 +49,9 @@ namespace kt
 
         QUrl url = QUrl(text);
 
+        connect(m_buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+        connect(m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
+
         if (url.isValid())
             m_url->setText(text);
 
@@ -73,14 +81,14 @@ namespace kt
         m_groups->addItems(grps);
     }
 
-    void PasteDialog::loadState(KSharedConfigPtr cfg)
+    void PasteDialog::loadState(KSharedConfig::Ptr cfg)
     {
         KConfigGroup g = cfg->group("PasteDlg");
         m_silently->setChecked(g.readEntry("silently", false));
         m_groups->setCurrentIndex(g.readEntry("group", 0));
     }
 
-    void PasteDialog::saveState(KSharedConfigPtr cfg)
+    void PasteDialog::saveState(KSharedConfig::Ptr cfg)
     {
         KConfigGroup g = cfg->group("PasteDlg");
         g.writeEntry("silently", m_silently->isChecked());
