@@ -41,7 +41,7 @@ namespace kt
         Q_OBJECT
     public:
         SpeedLimitsModel(Core* core, QObject* parent);
-        ~SpeedLimitsModel();
+        ~SpeedLimitsModel() override;
 
         int rowCount(const QModelIndex& parent) const override;
         int columnCount(const QModelIndex& parent) const override;
