@@ -42,7 +42,7 @@ namespace kt
         Q_OBJECT
     public:
         GroupViewModel(GroupManager* gman, View* view, QObject* parent);
-        ~GroupViewModel();
+        ~GroupViewModel() override;
 
         bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole) override;
         QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
