@@ -61,7 +61,7 @@ namespace kt
         Q_OBJECT
     public:
         TrayIcon(Core* tc, GUI* parent);
-        ~TrayIcon();
+        ~TrayIcon() override;
 
         /// Update stats for system tray icon
         void updateStats(const CurrentStats& stats);
@@ -175,7 +175,7 @@ namespace kt
             UPLOAD, DOWNLOAD
         };
         SetMaxRate(Core* tc, Type t, QWidget* parent);
-        ~SetMaxRate();
+        ~SetMaxRate() override;
 
     public slots:
         void update();
