@@ -17,10 +17,11 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #include "magnetmanager.h"
+
 #include <QFile>
 #include <QTextStream>
-#include <QSet>
 
 #include <util/log.h>
 #include <bcodec/bencoder.h>
@@ -114,10 +115,10 @@ MagnetManager::MagnetManager(QObject *parent)
 
 MagnetManager::~MagnetManager()
 {
-    foreach (DownloadSlot* slot, usedDownloadingSlots)
+    for (DownloadSlot* slot : qAsConst(usedDownloadingSlots))
         delete slot;
 
-    foreach (DownloadSlot* slot, freeDownloadingSlots)
+    for (DownloadSlot* slot : qAsConst(freeDownloadingSlots))
         delete slot;
 }
 
@@ -339,7 +340,7 @@ void MagnetManager::setUseSlotTimer(bool value)
 
     if (!useSlotTimer)
     {
-        foreach (DownloadSlot* slot, usedDownloadingSlots)
+        for (DownloadSlot* slot : qAsConst(usedDownloadingSlots))
         {
             slot->stopTimer();
             slot->setTimerDuration(timerDuration);
@@ -347,7 +348,7 @@ void MagnetManager::setUseSlotTimer(bool value)
     }
     else
     {
-        foreach (DownloadSlot* slot, usedDownloadingSlots)
+        for (DownloadSlot* slot : qAsConst(usedDownloadingSlots))
         {
             if (!slot->isTimerActived())
             {
@@ -361,10 +362,10 @@ void MagnetManager::setUseSlotTimer(bool value)
 void MagnetManager::setTimerDuration(bt::Uint32 duration)
 {
     timerDuration = duration * 60000; // convert to milliseconds
-    foreach (DownloadSlot* slot, usedDownloadingSlots)
+    for (DownloadSlot* slot : qAsConst(usedDownloadingSlots))
         slot->setTimerDuration(timerDuration);
 
-    foreach (DownloadSlot* slot, freeDownloadingSlots)
+    for (DownloadSlot* slot : qAsConst(freeDownloadingSlots))
         slot->setTimerDuration(timerDuration);
 
     emit updateQueue(0, usedDownloadingSlots.size());
@@ -372,7 +373,7 @@ void MagnetManager::setTimerDuration(bt::Uint32 duration)
 
 void MagnetManager::update()
 {
-    foreach (DownloadSlot* slot, usedDownloadingSlots)
+    for (DownloadSlot* slot : qAsConst(usedDownloadingSlots))
         magnetQueue.at(slot->getMagnetIndex())->update();
 
     emit updateQueue(0, usedDownloadingSlots.size());
@@ -397,7 +398,7 @@ void MagnetManager::loadMagnets(const QString& file)
     {
         node = decoder.decode();
         if (!node || node->getType() != BNode::LIST)
-            throw Error("Corrupted magnet file");
+            throw Error(QStringLiteral("Corrupted magnet file"));
 
         BListNode* ml = (BListNode*)node;
         for (Uint32 i = 0; i < ml->getNumChildren(); i++)
@@ -428,7 +429,7 @@ void MagnetManager::loadMagnets(const QString& file)
 void MagnetManager::saveMagnets(const QString& file)
 {
     File fptr;
-    if (!fptr.open(file, "wb"))
+    if (!fptr.open(file, QStringLiteral("wb")))
     {
         Out(SYS_GEN | LOG_NOTICE) << "Failed to open " << file << " : " << fptr.errorString() << endl;
         return;
@@ -437,10 +438,10 @@ void MagnetManager::saveMagnets(const QString& file)
     BEncoder enc(&fptr);
     enc.beginList();
 
-    foreach (MagnetDownloader* md, magnetQueue)
+    for (MagnetDownloader* md : qAsConst(magnetQueue))
         writeEncoderInfo(enc, md);
 
-    foreach (MagnetDownloader* md, stoppedList)
+    for (MagnetDownloader* md : qAsConst(stoppedList))
         writeEncoderInfo(enc, md);
 
     enc.end();
@@ -481,7 +482,7 @@ const MagnetDownloader *MagnetManager::getMagnetDownloader(bt::Uint32 idx) const
 {
     Q_ASSERT(idx < (Uint32) magnetHashes.size());
 
-    MagnetDownloader* md = 0;
+    MagnetDownloader* md = nullptr;
 
     Uint32 downloadQueueSize = magnetQueue.size();
     if (idx < downloadQueueSize)
