@@ -18,9 +18,13 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
  ***************************************************************************/
-#include <kgenericfactory.h>
-#include <knotification.h>
-#include <kmainwindow.h>
+
+#include "ipfilterplugin.h"
+
+#include <KNotification>
+#include <KMainWindow>
+#include <KPluginFactory>
+
 #include <QTimer>
 
 #include <interfaces/coreinterface.h>
@@ -31,22 +35,21 @@
 #include <util/logsystemmanager.h>
 #include <peer/accessmanager.h>
 
-
-#include "ipfilterplugin.h"
 #include "ipfilterpluginsettings.h"
 #include "ipblocklist.h"
 
 using namespace bt;
 
-K_EXPORT_COMPONENT_FACTORY(ktipfilterplugin, KGenericFactory<kt::IPFilterPlugin>("ipfilterplugin"))
+K_PLUGIN_FACTORY_WITH_JSON(ktorrent_ipfilter, "ktorrent_ipfilter.json", registerPlugin<kt::IPFilterPlugin>();)
 
 namespace kt
 {
 
-    IPFilterPlugin::IPFilterPlugin(QObject* parent, const QStringList& args) : Plugin(parent)
+    IPFilterPlugin::IPFilterPlugin(QObject* parent, const QVariantList& args)
+        : Plugin(parent)
     {
         Q_UNUSED(args);
-        connect(&auto_update_timer, SIGNAL(timeout()), this, SLOT(checkAutoUpdate()));
+        connect(&auto_update_timer, &QTimer::timeout, this, &IPFilterPlugin::checkAutoUpdate);
         auto_update_timer.setSingleShot(true);
     }
 
@@ -59,7 +62,7 @@ namespace kt
     {
         LogSystemManager::instance().registerSystem(i18n("IP Filter"), SYS_IPF);
         pref = new IPBlockingPrefPage(this);
-        connect(pref, SIGNAL(updateFinished()), this, SLOT(checkAutoUpdate()));
+        connect(pref, &IPBlockingPrefPage::updateFinished, this, &IPFilterPlugin::checkAutoUpdate);
         getGUI()->addPrefPage(pref);
 
         if (IPBlockingPluginSettings::useLevel1())
@@ -73,7 +76,7 @@ namespace kt
         LogSystemManager::instance().unregisterSystem(i18n("IP Filter"));
         getGUI()->removePrefPage(pref);
         delete pref;
-        pref = 0;
+        pref = nullptr;
         if (ip_filter)
         {
             AccessManager::instance().removeBlockList(ip_filter.data());
@@ -87,7 +90,7 @@ namespace kt
             return true;
 
         ip_filter.reset(new IPBlockList());
-        if (!ip_filter->load(kt::DataDir() + "level1.dat"))
+        if (!ip_filter->load(kt::DataDir() + QStringLiteral("level1.dat")))
         {
             ip_filter.reset();
             return false;
@@ -115,7 +118,7 @@ namespace kt
 
     bool IPFilterPlugin::versionCheck(const QString& version) const
     {
-        return version == KT_VERSION_MACRO;
+        return version == QStringLiteral(KT_VERSION_MACRO);
     }
 
     void IPFilterPlugin::checkAutoUpdate()
@@ -138,7 +141,7 @@ namespace kt
         {
             QDateTime last_updated = g.readEntry("last_updated", QDateTime());
             QDateTime next_update;
-            if (last_updated.isEmpty())
+            if (last_updated.isNull())
                 next_update = now.addDays(IPBlockingPluginSettings::autoUpdateInterval());
             else
                 next_update = QDateTime(last_updated).addDays(IPBlockingPluginSettings::autoUpdateInterval());
@@ -159,7 +162,9 @@ namespace kt
 
     void IPFilterPlugin::notification(const QString& msg)
     {
-        KNotification::event("PluginEvent", msg, QPixmap(), getGUI()->getMainWindow());
+        KNotification::event(QStringLiteral("PluginEvent"), msg, QPixmap(), getGUI()->getMainWindow());
     }
 
 }
+
+#include <ipfilterplugin.moc>
