@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 by Ivan Vasić                                     *
+ *   Copyright (C) 2006 by Ivan Vasić                                      *
  *   ivasic@gmail.com                                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -17,12 +17,13 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #include "scanfolderplugin.h"
 #include "scanfolderprefpage.h"
 
-#include <klocalizedstring.h>
-#include <kglobal.h>
-#include <kfiledialog.h>
+#include <QFileDialog>
+#include <KLocalizedString>
+
 #include <util/functions.h>
 #include <groups/groupmanager.h>
 #include <interfaces/coreinterface.h>
@@ -34,14 +35,14 @@ namespace kt
 {
 
     ScanFolderPrefPage::ScanFolderPrefPage(ScanFolderPlugin* plugin, QWidget* parent)
-        : PrefPageInterface(ScanFolderPluginSettings::self(), i18nc("plugin name", "Scan Folder"), "folder-open", parent), m_plugin(plugin)
+        : PrefPageInterface(ScanFolderPluginSettings::self(), i18nc("plugin name", "Scan Folder"), QStringLiteral("folder-open"), parent), m_plugin(plugin)
     {
         setupUi(this);
-        connect(kcfg_actionDelete, SIGNAL(toggled(bool)), kcfg_actionMove, SLOT(setDisabled(bool)));
-        connect(m_add, SIGNAL(clicked()), this, SLOT(addPressed()));
-        connect(m_remove, SIGNAL(clicked()), this, SLOT(removePressed()));
-        connect(m_folders, SIGNAL(itemSelectionChanged()), this, SLOT(selectionChanged()));
-        connect(m_group, SIGNAL(currentIndexChanged(int)), this, SLOT(currentGroupChanged(int)));
+        connect(kcfg_actionDelete, &QCheckBox::toggled, kcfg_actionMove, &QCheckBox::setDisabled);
+        connect(m_add, &QPushButton::clicked, this, &ScanFolderPrefPage::addPressed);
+        connect(m_remove, &QPushButton::clicked, this, &ScanFolderPrefPage::removePressed);
+        connect(m_folders, &QListWidget::itemSelectionChanged, this, &ScanFolderPrefPage::selectionChanged);
+        connect(m_group, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &ScanFolderPrefPage::currentGroupChanged);
     }
 
 
@@ -80,7 +81,7 @@ namespace kt
         folders = ScanFolderPluginSettings::folders();
         foreach (const QString& f, folders)
         {
-            m_folders->addItem(new QListWidgetItem(QIcon::fromTheme("folder"), f));
+            m_folders->addItem(new QListWidgetItem(QIcon::fromTheme(QStringLiteral("folder")), f));
         }
         selectionChanged();
     }
@@ -107,13 +108,12 @@ namespace kt
 
     void ScanFolderPrefPage::addPressed()
     {
-        KUrl dir = KFileDialog::getExistingDirectoryUrl(KUrl("kfiledialog:///openTorrent"), this);
-        if (dir.isValid())
+        QString p = QFileDialog::getExistingDirectory(this);
+        if (!p.isEmpty())
         {
-            QString p = dir.toLocalFile();
             if (!p.endsWith(bt::DirSeparator()))
                 p += bt::DirSeparator();
-            m_folders->addItem(new QListWidgetItem(QIcon::fromTheme("folder"), p));
+            m_folders->addItem(new QListWidgetItem(QIcon::fromTheme(QStringLiteral("folder")), p));
             folders.append(p);
         }
 
