@@ -41,7 +41,7 @@ namespace kt
         UpdateFolderEvent() : QEvent((QEvent::Type)UPDATE_FOLDER_EVENT)
         {}
 
-        ~UpdateFolderEvent()
+        ~UpdateFolderEvent() override
         {}
     };
 
@@ -51,7 +51,7 @@ namespace kt
         RecursiveScanEvent(const QUrl& url) : QEvent((QEvent::Type)RECURSIVE_SCAN_EVENT), url(url)
         {}
 
-        ~RecursiveScanEvent()
+        ~RecursiveScanEvent() override
         {}
 
         QUrl url;
@@ -156,6 +156,11 @@ namespace kt
     void ScanThread::stop()
     {
         stop_requested = true;
+
+        // XXX seems like deleting KDirWatch object(s) created in scan_folders
+        // in destructor of this QThread after it has been stopped
+        // causes memory corruption, so we delete them early
+        scan_folders.clear();
         exit();
         wait();
     }
