@@ -24,7 +24,7 @@ namespace kt
 {
 
     SettingsPage::SettingsPage(QWidget* p) :
-        PrefPageInterface(StatsPluginSettings::self(), i18nc("@title:window", "Statistics"), "view-statistics", p)
+        PrefPageInterface(StatsPluginSettings::self(), i18nc("@title:window", "Statistics"), QStringLiteral("view-statistics"), p)
     {
         setupUi(this);
         connect(kcfg_UpdateEveryGuiUpdates, SIGNAL(valueChanged(int)), this, SLOT(UpdGuiUpdatesToMs(int)));
