@@ -23,7 +23,7 @@
 
 #include <QWidget>
 
-#include <kcolorbutton.h>
+#include <KColorButton>
 
 #include <interfaces/prefpageinterface.h>
 
@@ -51,10 +51,10 @@ namespace kt
         */
         SettingsPage(QWidget* p);
         ///Destructor
-        virtual ~SettingsPage();
+        ~SettingsPage() override;
 
     public slots:
-        void updateSettings();
+        void updateSettings() override;
 
     private slots:
         void UpdGuiUpdatesToMs(int);
