@@ -18,11 +18,12 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #ifndef KTFEEDWIDGETMODEL_H
 #define KTFEEDWIDGETMODEL_H
 
 #include <QAbstractTableModel>
-#include <syndication/item.h>
+#include <Syndication/Item>
 
 namespace kt
 {
@@ -38,22 +39,20 @@ namespace kt
         Q_OBJECT
     public:
         FeedWidgetModel(QObject* parent);
-        virtual ~FeedWidgetModel();
+        ~FeedWidgetModel();
 
         Feed* currentFeed() {return feed;}
         void setCurrentFeed(Feed* f);
 
-        virtual int rowCount(const QModelIndex& parent) const;
-        virtual int columnCount(const QModelIndex& parent) const;
-        virtual QVariant headerData(int section, Qt::Orientation orientation, int role) const;
-        virtual QVariant data(const QModelIndex& index, int role) const;
-        virtual bool removeRows(int row, int count, const QModelIndex& parent);
-        virtual bool insertRows(int row, int count, const QModelIndex& parent);
+        int rowCount(const QModelIndex& parent) const override;
+        int columnCount(const QModelIndex& parent) const override;
+        QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
+        QVariant data(const QModelIndex& index, int role) const override;
+        bool removeRows(int row, int count, const QModelIndex& parent) override;
+        bool insertRows(int row, int count, const QModelIndex& parent) override;
 
         Syndication::ItemPtr itemForIndex(const QModelIndex& idx);
-    private:
 
-    private slots:
         void updated();
 
     private:
