@@ -18,12 +18,16 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
+#include <QMimeType>
+#include <QMimeDatabase>
 #include <QRegExp>
-#include <kmimetype.h>
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
-#include <kio/job.h>
-#include <kio/jobuidelegate.h>
+
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KIO/Job>
+#include <KIO/JobUiDelegate>
+
 #include <magnet/magnetlink.h>
 #include <interfaces/coreinterface.h>
 #include <interfaces/torrentinterface.h>
@@ -38,7 +42,7 @@ using namespace bt;
 namespace kt
 {
 
-    LinkDownloader::LinkDownloader(const KUrl& url,
+    LinkDownloader::LinkDownloader(const QUrl& url,
                                    kt::CoreInterface* core,
                                    bool verbose,
                                    const QString& group,
@@ -47,23 +51,23 @@ namespace kt
         : url(url), core(core), verbose(verbose), group(group),
           location(location), move_on_completion(move_on_completion)
     {
-        base_url = url.protocol() + "://" + url.host();
+        base_url = url.scheme() + QStringLiteral("://") + url.host();
         if (url.port(80) != 80)
-            base_url += ":" + QString::number(url.port(80));
+            base_url += QLatin1Char(':') + QString::number(url.port(80));
 
         QString path = url.path();
         if (path.size() > 0)
         {
             int idx = -1;
-            if (path.endsWith("/"))
-                base_url += (!path.startsWith("/") ? "/" : "") + path;
-            else if ((idx = path.lastIndexOf("/")) != -1)
+            if (path.endsWith(QLatin1Char('/')))
+                base_url += (!path.startsWith(QStringLiteral("/")) ? QStringLiteral("/") : QString()) + path;
+            else if ((idx = path.lastIndexOf(QStringLiteral("/"))) != -1)
                 base_url += path.mid(0, idx + 1);
             else
-                base_url += "/";
+                base_url += QLatin1Char('/');
         }
         else
-            base_url += "/";
+            base_url += QLatin1Char('/');
     }
 
 
@@ -76,9 +80,9 @@ namespace kt
         KIO::StoredTransferJob* job = (KIO::StoredTransferJob*)j;
         if (job->error())
         {
-            Out(SYS_SYN | LOG_NOTICE) << "Failed to download " << url.prettyUrl() << " : " << job->errorString() << endl;
+            Out(SYS_SYN | LOG_NOTICE) << "Failed to download " << url.toDisplayString() << " : " << job->errorString() << endl;
             if (verbose)
-                job->ui()->showErrorMessage();
+                job->uiDelegate()->showErrorMessage();
 
             finished(false);
             deleteLater();
@@ -101,8 +105,8 @@ namespace kt
         }
         else
         {
-            KMimeType::Ptr data_type = KMimeType::findByContent(job->data());
-            if (data_type && data_type->name().contains("html"))
+            QMimeType data_type = QMimeDatabase().mimeTypeForData(job->data());
+            if (data_type.isValid() && data_type.name().contains(QStringLiteral("html")))
                 handleHtmlPage(job->data());
         }
     }
@@ -110,7 +114,7 @@ namespace kt
     void LinkDownloader::start()
     {
         KIO::StoredTransferJob* j = KIO::storedGet(url, KIO::Reload, verbose ? KIO::DefaultFlags : KIO::HideProgressInfo);
-        connect(j, SIGNAL(result(KJob*)), this, SLOT(downloadFinished(KJob*)));
+        connect(j, &KIO::StoredTransferJob::result, this, &LinkDownloader::downloadFinished);
     }
 
     bool LinkDownloader::isTorrent(const QByteArray& data) const
@@ -134,13 +138,13 @@ namespace kt
 
     void LinkDownloader::handleHtmlPage(const QByteArray& data)
     {
-        QRegExp rx("href\\s*=\"([^\"]*)\"", Qt::CaseInsensitive);
-        QString str(data);
+        QRegExp rx(QLatin1String("href\\s*=\"([^\"]*)\""), Qt::CaseInsensitive);
+        QString str(QString::fromUtf8(data));
         int pos = 0;
         while ((pos = rx.indexIn(str, pos)) != -1)
         {
             QString href_link = rx.cap(1);
-            if (href_link.startsWith("magnet:") && href_link.contains("xt=urn:btih:"))
+            if (href_link.startsWith(QStringLiteral("magnet:")) && href_link.contains(QStringLiteral("xt=urn:btih:")))
             {
                 MagnetLinkLoadOptions options;
                 options.silently = verbose;
@@ -152,15 +156,15 @@ namespace kt
                 deleteLater();
                 return;
             }
-            else if (!href_link.startsWith("http://") && !href_link.startsWith("https://"))
+            else if (!href_link.startsWith(QStringLiteral("http://")) && !href_link.startsWith(QStringLiteral("https://")))
             {
-                if (!href_link.startsWith("/"))
+                if (!href_link.startsWith(QStringLiteral("/")))
                     href_link = base_url + href_link;
                 else
-                    href_link = url.protocol() + "://" + url.authority() + href_link;
+                    href_link = url.scheme() + QStringLiteral("://") + url.authority() + href_link;
             }
 
-            link_url = KUrl(href_link);
+            link_url = QUrl(href_link);
             if (link_url.isValid())
                 links.append(link_url);
 
@@ -173,14 +177,14 @@ namespace kt
     void LinkDownloader::tryTorrentLinks()
     {
         // First try links ending with .torrent
-        foreach (KUrl u, links)
+        foreach (QUrl u, links)
         {
-            if (u.path().endsWith(".torrent") || u.path().endsWith(".TORRENT"))
+            if (u.path().endsWith(QStringLiteral(".torrent")) || u.path().endsWith(QStringLiteral(".TORRENT")))
             {
-                Out(SYS_SYN | LOG_DEBUG) << "Trying torrent link: " << u.prettyUrl() << endl;
+                Out(SYS_SYN | LOG_DEBUG) << "Trying torrent link: " << u.toDisplayString() << endl;
                 link_url = u;
                 KIO::StoredTransferJob* j = KIO::storedGet(u, KIO::Reload, verbose ? KIO::DefaultFlags : KIO::HideProgressInfo);
-                connect(j, SIGNAL(result(KJob*)), this, SLOT(torrentDownloadFinished(KJob*)));
+                connect(j, &KIO::StoredTransferJob::result, this, &LinkDownloader::torrentDownloadFinished);
                 links.removeAll(u);
                 return;
             }
@@ -194,9 +198,9 @@ namespace kt
     {
         if (links.count() == 0)
         {
-            Out(SYS_SYN | LOG_DEBUG) << "Couldn't find a valid link to a torrent on " << url.prettyUrl() << endl;
+            Out(SYS_SYN | LOG_DEBUG) << "Couldn't find a valid link to a torrent on " << url.toDisplayString() << endl;
             if (verbose)
-                KMessageBox::error(0, i18n("Could not find a valid link to a torrent on %1", url.prettyUrl()));
+                KMessageBox::error(0, i18n("Could not find a valid link to a torrent on %1", url.toDisplayString()));
 
             finished(false);
             deleteLater();
@@ -206,8 +210,8 @@ namespace kt
         link_url = links.front();
         links.pop_front();
         KIO::StoredTransferJob* j = KIO::storedGet(link_url, KIO::Reload, KIO::HideProgressInfo);
-        connect(j, SIGNAL(result(KJob*)), this, SLOT(torrentDownloadFinished(KJob*)));
-        Out(SYS_SYN | LOG_DEBUG) << "Trying " << link_url.prettyUrl() << endl;
+        connect(j, &KIO::StoredTransferJob::result, this, &LinkDownloader::torrentDownloadFinished);
+        Out(SYS_SYN | LOG_DEBUG) << "Trying " << link_url.toDisplayString() << endl;
     }
 
     void LinkDownloader::torrentDownloadFinished(KJob* j)
@@ -219,7 +223,7 @@ namespace kt
             {
                 Out(SYS_SYN | LOG_NOTICE) << "Failed to download torrent: " << job->errorString() << endl;
                 if (verbose)
-                    job->ui()->showErrorMessage();
+                    job->uiDelegate()->showErrorMessage();
 
                 finished(false);
                 deleteLater();
